use serde::{Serialize, Deserialize};
use tetratto_shared::{snow::Snowflake, unix_epoch_timestamp};

#[derive(Serialize, Deserialize, Clone, Debug)]
pub struct Link {
    pub id: usize,
    pub created: usize,
    /// Links should be selected by their owner, not their link list ID.
    /// This is why we do not store link list ID.
    pub owner: usize,
    pub label: String,
    pub href: String,
    /// As link icons are optional, `upload_id` is allowed to be 0.
    pub upload_id: usize,
    /// Clicks are tracked for supporters only.
    ///
    /// When a user clicks on a link through the UI, they'll be redirect to
    /// `/links/{id}`. If the link's owner is a supporter, the link's clicks will
    /// be incremented.
    ///
    /// The page should just serve a simple HTML document with a meta tag to redirect.
    /// We only really care about knowing they clicked it, so an automatic redirect will do.
    pub clicks: usize,
    pub position: usize,
}

impl Link {
    /// Create a new [`Link`].
    pub fn new(owner: usize, label: String, href: String, position: usize) -> Self {
        Self {
            id: Snowflake::new().to_string().parse::<usize>().unwrap(),
            created: unix_epoch_timestamp(),
            owner,
            label,
            href,
            upload_id: 0,
            clicks: 0,
            position,
        }
    }
}
